# `easy-px4-utils`

Set of utility function to parse information.

> [!IMPORTANT]
> This is a core, and critical package for our package: [`eolab_drones`](https://github.com/EOLab-HSRW/drones-fw/tree/main).
